Learn R Programming

speedglm (version 0.3-2)

speedglm-package: Fitting Linear and Generalized Linear Models to Large Data Sets

Description

Fits Linear and Generalized Linear Models to large data sets. For data loaded in R memory the fitting is usually fast, especially if R is linked against an optimized BLAS. For data sets of size greater of R memory, the fitting is made by an updating algorithm.

Arguments

Details

Package: speedglm
Type: Package
Version: 0.3-1
Date: 2015-09-09
Depends: Matrix, stats, MASS
License: GPL
LazyLoad: yes