Fits Linear and Generalized Linear Models to large data sets. For data loaded in R memory the fitting is usually fast, especially if R is linked against an optimized BLAS. For data sets of size greater of R memory, the fitting is made by an updating algorithm.
| Package: | speedglm |
| Type: | Package |
| Version: | 0.3-1 |
| Date: | 2015-09-09 |
| Depends: | Matrix, stats, MASS |
| License: | GPL |
| LazyLoad: | yes |